@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004-2006 Patrice Tremblay <tremblaypatrice@yahoo.fr>
+Copyright (C) 2004-2007 Patrice Tremblay <tremblaypatrice@yahoo.fr>
 			http://www.poplix.info/lipstik
 
 based on plastik:
@@ -184,6 +184,11 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
 	hbox3->layout()->addItem(new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum) );
 	checkMarkColor = new KColorButton(hbox3);
 
+	customTabHighlightColor = new QCheckBox(i18n("Active tab highlight :"), otherGrp);
+	QHBox *hbox4 = new QHBox(otherGrp);
+	hbox4->layout()->addItem(new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum) );
+	tabHighlightColor = new KColorButton(hbox4);
+
 	tabLayout->addWidget(otherGrp,1,2,0);	
 
 	///Init tab2
@@ -203,6 +208,7 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
 	QLabel* ksLabel;
 	QLabel* peLabel;
 	QLabel* bastianLabel;
+	QLabel* pcbsdLabel;
 	QLabel* othersLabel;
 
         layout = new QVBoxLayout(page2, 10, -1);
@@ -210,7 +216,7 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
 	tabWidget->insertTab(page2, i18n("About"));
 
 	lipstikLabel = new QLabel(page2);
-        lipstikLabel->setText(i18n("Lipstik 2.2.2"));
+        lipstikLabel->setText(i18n("Lipstik 2.2.3"));
 	lipstikLabel->setFrameStyle( QFrame::StyledPanel | QFrame::Raised );
 
 	authorLabel = new QLabel(page2);
@@ -253,7 +259,10 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
         peLabel->setText(i18n("    Polyester [thanks to Marco Martin]."));
 
 	bastianLabel = new QLabel(page2);
-        bastianLabel->setText(i18n("Also thanks to Bastian Venthur, the Debian maintainer of kde-style-lipstik."));
+        bastianLabel->setText(i18n("Thanks to Bastian Venthur, the Debian maintainer of kde-style-lipstik."));
+
+	pcbsdLabel = new QLabel(page2);
+        pcbsdLabel->setText(i18n("Thanks to Charles A. Landemaine, of PC-BSD, for the feature suggestion."));
 
 	othersLabel = new QLabel(page2);
         othersLabel->setText(i18n("Special thanks to Dominique and all the kde-look.org users."));
@@ -279,6 +288,7 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
 
 	layout->addSpacing(10);
 	layout->add(bastianLabel);
+	layout->add(pcbsdLabel);
 	layout->add(othersLabel);
 
 	///Populate!
@@ -386,6 +396,12 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
 	origCheckMarkColor = s.readEntry("/lipstikstyle/Settings/checkMarkColor", "/Qt/KWinPalette/activeBackground");
 	checkMarkColor->setColor(origCheckMarkColor);
 
+	origCustomTabHighlightColor = s.readBoolEntry("/lipstikstyle/Settings/customTabHighlightColor", false);
+	customTabHighlightColor->setChecked(origCustomTabHighlightColor);
+
+	origTabHighlightColor = s.readEntry("/lipstikstyle/Settings/tabHighlightColor", "/Qt/KWinPalette/activeBackground");
+	tabHighlightColor->setColor(origTabHighlightColor);
+
 	connect(reverseGradients, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
 	connect(paintGroove, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
 	connect(sharperMenuGradient, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
@@ -420,6 +436,8 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
 	connect(focusHighlightColor, SIGNAL( pressed() ), SLOT( updateChanged() ) );
 	connect(customCheckMarkColor, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
 	connect(checkMarkColor, SIGNAL( pressed() ), SLOT( updateChanged() ) );
+	connect(customTabHighlightColor, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
+	connect(tabHighlightColor, SIGNAL( pressed() ), SLOT( updateChanged() ) );
 
 	//Menu Stripe 
 	if ( menuLeftSideBar->isChecked() ) {
@@ -459,6 +477,12 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
 	else
 	 checkMarkColor->setEnabled(false);
 
+	//Custom tab highlight color.
+	if ( customTabHighlightColor->isChecked() )
+	 tabHighlightColor->setEnabled(true);
+	else
+	 tabHighlightColor->setEnabled(false);
+
 	if ( customOverHighlightColor->isChecked() )
 	 overHighlightColor->setEnabled(true);
 	else
@@ -507,6 +531,8 @@ void LipstikStyleConfig::save()
 	s.writeEntry("/lipstikstyle/Settings/focusHighlightColor", QColor(focusHighlightColor->color()).name());
 	s.writeEntry("/lipstikstyle/Settings/customCheckMarkColor", customCheckMarkColor->isChecked());
 	s.writeEntry("/lipstikstyle/Settings/checkMarkColor", QColor(checkMarkColor->color()).name());
+	s.writeEntry("/lipstikstyle/Settings/customTabHighlightColor", customTabHighlightColor->isChecked());
+	s.writeEntry("/lipstikstyle/Settings/tabHighlightColor", QColor(tabHighlightColor->color()).name());
 }
 
 void LipstikStyleConfig::defaults()
@@ -545,6 +571,8 @@ void LipstikStyleConfig::defaults()
 	focusHighlightColor->setColor("/Qt/KWinPalette/activeBackground");
 	customCheckMarkColor->setChecked(false);
 	checkMarkColor->setColor("/Qt/KWinPalette/activeBackground");
+	customTabHighlightColor->setChecked(false);
+	tabHighlightColor->setColor("/Qt/KWinPalette/activeBackground");
 	//updateChanged would be done by setChecked already
 }
 
@@ -601,6 +629,11 @@ void LipstikStyleConfig::updateChanged()
 	else
 	 checkMarkColor->setEnabled(false);
 
+	if ( customTabHighlightColor->isChecked() )
+	 tabHighlightColor->setEnabled(true);
+	else
+	 tabHighlightColor->setEnabled(false);
+
 	if ((animateProgressBar->isChecked() == origAnimProgressBar) &&
 	    (reverseGradients->isChecked() == origReverseGradients) &&
 	    (paintGroove->isChecked() == origPaintGroove) &&
@@ -632,6 +665,8 @@ void LipstikStyleConfig::updateChanged()
 	    (focusHighlightColor->color() == origFocusHighlightColor) &&
 	    (customCheckMarkColor->isChecked() == origCustomCheckMarkColor) &&
 	    (checkMarkColor->color() == origCheckMarkColor) &&
+	    (customTabHighlightColor->isChecked() == origCustomTabHighlightColor) &&
+	    (tabHighlightColor->color() == origTabHighlightColor) &&
 	    (scrollBarStyle->currentText() == origScrollBarStyle) &&
 	    (scrollBarWidth->currentText() == origScrollBarWidth) &&
 	    (sliderStyle->currentText() == origSliderStyle)
